@@ -1,5 +1,5 @@
 package Beam::Runner::Command::run;
-our $VERSION = '0.001';
+our $VERSION = '0.002';
 # ABSTRACT: Run the given service with the given arguments
 
 #pod =head1 SYNOPSIS
@@ -21,39 +21,11 @@ use warnings;
 use Beam::Wire;
 use Path::Tiny qw( path );
 use Scalar::Util qw( blessed );
-
-# File extensions to try to find, starting with no extension (which is
-# to say the extension is given by the user's input)
-my @EXTS = ( "", qw( .yml .yaml .json .xml .pl ) );
+use Beam::Runner::Util qw( find_container_path );
 
 sub run {
     my ( $class, $container, $service_name, @args ) = @_;
-    my $path;
-    if ( path( $container )->is_file ) {
-        $path = path( $container );
-    }
-    else {
-        my @dirs = ( "." );
-        if ( $ENV{BEAM_PATH} ) {
-            push @dirs, split /:/, $ENV{BEAM_PATH};
-        }
-
-        DIR: for my $dir ( @dirs ) {
-            my $d = path( $dir );
-            for my $ext ( @EXTS ) {
-                my $f = $d->child( $container . $ext );
-                if ( $f->exists ) {
-                    $path = $f;
-                    last DIR;
-                }
-            }
-        }
-
-        die sprintf qq{Could not find container "%s" in directories: %s\n},
-            $container, join( ":", @dirs )
-            unless $path;
-    }
-
+    my $path = find_container_path( $container );
     my $wire = Beam::Wire->new(
         file => $path,
     );
@@ -82,7 +54,7 @@ Beam::Runner::Command::run - Run the given service with the given arguments
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
